summaryrefslogtreecommitdiffstats
path: root/kdevdesigner/designer/dbconnectionimpl.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kdevdesigner/designer/dbconnectionimpl.cpp')
-rw-r--r--kdevdesigner/designer/dbconnectionimpl.cpp16
1 files changed, 8 insertions, 8 deletions
diff --git a/kdevdesigner/designer/dbconnectionimpl.cpp b/kdevdesigner/designer/dbconnectionimpl.cpp
index fb5697ca..d326df8a 100644
--- a/kdevdesigner/designer/dbconnectionimpl.cpp
+++ b/kdevdesigner/designer/dbconnectionimpl.cpp
@@ -1,15 +1,15 @@
/**********************************************************************
** Copyright (C) 2000 Trolltech AS. All rights reserved.
**
** This file is part of Qt Designer.
**
** This file may be distributed and/or modified under the terms of the
** GNU General Public License version 2 as published by the Free Software
** Foundation and appearing in the file LICENSE.GPL included in the
** packaging of this file.
**
-** Licensees holding valid Qt Enterprise Edition or Qt Professional Edition
-** licenses may use this file in accordance with the Qt Commercial License
+** Licensees holding valid TQt Enterprise Edition or TQt Professional Edition
+** licenses may use this file in accordance with the TQt Commercial License
** Agreement provided with the Software.
**
** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
@@ -17,7 +17,7 @@
**
** See http://www.trolltech.com/gpl/ for GPL licensing information.
** See http://www.trolltech.com/pricing.html or email sales@trolltech.com for
-** information about Qt Commercial License Agreements.
+** information about TQt Commercial License Agreements.
**
** Contact info@trolltech.com if any conditions of this licensing are
** not clear to you.
@@ -35,9 +35,9 @@
#include <tqlayout.h>
#include <tqsqldatabase.h>
-DatabaseConnectionEditor::DatabaseConnectionEditor( DatabaseConnection* connection, TQWidget* parent,
+DatabaseConnectionEditor::DatabaseConnectionEditor( DatabaseConnection* connection, TQWidget* tqparent,
const char* name, bool modal, WFlags fl )
- : DatabaseConnectionEditorBase( parent, name, modal, fl ), conn( connection )
+ : DatabaseConnectionEditorBase( tqparent, name, modal, fl ), conn( connection )
{
connectionWidget = new DatabaseConnectionWidget( grp );
grpLayout->addWidget( connectionWidget, 0, 0 );
@@ -50,7 +50,7 @@ DatabaseConnectionEditor::~DatabaseConnectionEditor()
void DatabaseConnectionEditor::accept()
{
-#ifndef QT_NO_SQL
+#ifndef TQT_NO_SQL
conn->setUsername( connectionWidget->editUsername->text() );
conn->setPassword( connectionWidget->editPassword->text() );
conn->setHostname( connectionWidget->editHostname->text() );
@@ -61,7 +61,7 @@ void DatabaseConnectionEditor::accept()
void DatabaseConnectionEditor::init()
{
connectionWidget->editName->setEnabled( FALSE );
- connectionWidget->editName->setValidator( new AsciiValidator( connectionWidget->editName ) );
+ connectionWidget->editName->setValidator( new AsciiValidator( TQT_TQOBJECT(connectionWidget->editName) ) );
connectionWidget->editName->setText( conn->name() );
connectionWidget->comboDriver->setEnabled( FALSE );
connectionWidget->comboDriver->lineEdit()->setText( conn->driver() );
@@ -1,15 +1,15 @@
** Copyright (C) 2000 Trolltech AS. All rights reserved.
**
-** This file is part of Qt Designer.
+** This file is part of TQt Designer.
**
** This file may be distributed and/or modified under the terms of the